@@ -344,7 +344,9 @@ sub check_filename {
     }
     elsif ($filename =~ m/\A
                           (
-                              [a-zA-Z0-9-]+
+                              [a-zA-Z0-9]
+                              [a-zA-Z0-9-]*
+                              [a-zA-Z0-9]
                               (\.(pdf|jpe?g|png))?
                           )
                           \z/x) {
@@ -447,6 +449,7 @@ has cover      => (is => 'rw',
                   );
 
 sub _check_coverwidth {
+    # compare with  MuseHeader
     my $width = $_[0];
     die "$width should be a number" unless $width;
     if ($width =~ m/\A[01](\.[0-9][0-9]?)?\z/) {
